@@ -1,11 +1,17 @@
 import importlib
 import pathlib
+import sys
 
+import sh
 import typer
 
 from monarch_py.implementations.solr.solr_implementation import SolrImplementation
 
+SOLR_DATA = pathlib.Path(__file__).parent / "solr-data"
+
 app = typer.Typer()
+solr_app = typer.Typer()
+app.add_typer(solr_app, name="solr")
 
 
 @app.command()
@@ -74,6 +80,28 @@ def associations(
 
     print(response.json(indent=4))
 
+# _out_bufsize=100
+@solr_app.command("download")
+def get_solr():
+    sh.wget("https://data.monarchinitiative.org/monarch-kg-dev/latest/solr.tar.gz", "-O", "/tmp/solr.tar.gz", _out=sys.stdout, _err=sys.stderr)
+    sh.mkdir("-p", SOLR_DATA)
+    sh.tar("-zxf", "/tmp/solr.tar.gz", "-C", f"{SOLR_DATA}", _out=sys.stdout, _err=sys.stderr)
+    sh.rm("/tmp/solr.tar.gz")
+
+@solr_app.command("start")
+def start_solr():
+    data = pathlib.Path(f"{SOLR_DATA}/data")
+    sh.docker.run("-p", "8983:8983", "-v", f"{data}:/opt", "-e", "SOLR_HOME=/opt/data", "--name", "monarch_solr","solr:8", _out=sys.stdout, _err=sys.stderr)
+
+@solr_app.command("stop")
+def stop_solr():
+    sh.docker.stop("monarch_solr", _out=sys.stdout, _err=sys.stderr)
+    sh.docker.rm("monarch_solr")
+
+@solr_app.command("remove")
+def delete_solr():
+    sh.rm("-rf", SOLR_DATA)
+
 
 if __name__ == "__main__":
     app()
